# OctoprintPiSupport


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**model** | **str** |  | 
**throttle_state** | **str** |  | 
**octopi_version** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


